# Desktop App 

The eReuse.org Desktop-App is a Flask application supporting and report help-desk incidents.
Execute Workbench and also show information about eReuse.org and the social contribution.

## Testing

```python
from desktop_app.flaskapp import DesktopApp
app = DesktopApp()
app.run()
```